@@ -9,9 +9,13 @@ def test2():
     print("Still good to go.")
 
 def get_items():
+    global ITEMLIST
     path = os.path.join(os.path.dirname(__file__), "items.txt")
 
     if os.path.exists(path) and os.path.isfile(path):
+        print("path test: true")
+
         with open(path, "r") as file:
-            global ITEMLIST
             ITEMLIST = [item.strip() for item in file.readlines()]
+    else:
+        print("failed")
\ No newline at end of file
